@@ -25,7 +25,6 @@
 
 #include "config.h"
 
-#include <linux/input-event-codes.h>
 #include <linux/input.h>
 #include <wayland-client-protocol.h>
 
@@ -33,6 +32,7 @@
 #include "shared/timespec-util.h"
 #include "weston-test-client-helper.h"
 #include "weston-test-client-protocol.h"
+#include "weston-test-assert.h"
 
 struct constraints {
 	struct zwp_pointer_constraints_v1 *zwp_pointer_constraints;
@@ -77,7 +77,7 @@ pointer_locked_event(void *data, struct zwp_locked_pointer_v1 *locked_pointer)
 {
 	struct constraints *cs = data;
 
-	assert(locked_pointer == cs->zwp_locked_pointer);
+	test_assert_ptr_eq(locked_pointer, cs->zwp_locked_pointer);
 	cs->pointer_is_locked = true;
 }
 
@@ -86,7 +86,7 @@ pointer_unlocked_event(void *data, struct zwp_locked_pointer_v1 *locked_pointer)
 {
 	struct constraints *cs = data;
 
-	assert(locked_pointer == cs->zwp_locked_pointer);
+	test_assert_ptr_eq(locked_pointer, cs->zwp_locked_pointer);
 	cs->pointer_is_locked = false;
 }
 
@@ -100,7 +100,7 @@ pointer_confined_event(void *data, struct zwp_confined_pointer_v1 *confined_poin
 {
 	struct constraints *cs = data;
 
-	assert(confined_pointer == cs->zwp_confined_pointer);
+	test_assert_ptr_eq(confined_pointer, cs->zwp_confined_pointer);
 	cs->pointer_is_confined = true;
 }
 
@@ -109,7 +109,7 @@ pointer_unconfined_event(void *data, struct zwp_confined_pointer_v1 *confined_po
 {
 	struct constraints *cs = data;
 
-	assert(confined_pointer == cs->zwp_confined_pointer);
+	test_assert_ptr_eq(confined_pointer, cs->zwp_confined_pointer);
 	cs->pointer_is_confined = false;
 }
 
@@ -174,7 +174,7 @@ constraints_init(struct constraints *cs, struct client *client)
 	cs->zwp_pointer_constraints = bind_to_singleton_global(client,
 							       &zwp_pointer_constraints_v1_interface,
 							       1);
-	assert(cs->zwp_pointer_constraints);
+	test_assert_ptr_not_null(cs->zwp_pointer_constraints);
 }
 
 static void
@@ -209,29 +209,31 @@ TEST(constraints_events)
 	/* receive confined events for oneshot lifetime */
 	confine_pointer(&cs, client, &confined_pointer_listener, NULL,
 			ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_ONESHOT);
-	assert(cs.pointer_is_confined);
+	test_assert_true(cs.pointer_is_confined);
 	confine_destroy(&cs, client);
 
 	/* receive confined events for persistent lifetime */
 	confine_pointer(&cs, client, &confined_pointer_listener, NULL,
 			ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_PERSISTENT);
-	assert(cs.pointer_is_confined);
+	test_assert_true(cs.pointer_is_confined);
 	confine_destroy(&cs, client);
 
 	/* receive locked events for oneshot lifetime */
 	lock_pointer(&cs, client, &locked_pointer_listener, NULL,
 		     ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_ONESHOT);
-	assert(cs.pointer_is_locked);
+	test_assert_true(cs.pointer_is_locked);
 	lock_destroy(&cs, client);
 
 	/* receive locked events for persistent lifetime */
 	lock_pointer(&cs, client, &locked_pointer_listener, NULL,
 		     ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_PERSISTENT);
-	assert(cs.pointer_is_locked);
+	test_assert_true(cs.pointer_is_locked);
 	lock_destroy(&cs, client);
 
 	constraint_deinit(&cs);
 	client_destroy(client);
+
+	return RESULT_OK;
 }
 
 TEST(constraints_confined_boundaries_input_region)
@@ -249,43 +251,45 @@ TEST(constraints_confined_boundaries_input_region)
 	/* confine to whole surface */
 	confine_pointer(&cs, client, &confined_pointer_listener, NULL,
 			ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_ONESHOT);
-	assert(cs.pointer_is_confined);
+	test_assert_true(cs.pointer_is_confined);
 
 	/* move to boundary */
 	move_pointer(client, 100, 100);
 
 	/* x-1 (outside boundary) */
 	move_pointer(client, client->surface->x-1, client->surface->y);
-	assert(client->input->pointer->focus == client->surface);
-	assert(client->test->pointer_x == client->surface->x);
+	test_assert_ptr_eq(client->input->pointer->focus, client->surface);
+	test_assert_int_eq(client->test->pointer_x, client->surface->x);
 
 	/* y-1 (outside boundary) */
 	move_pointer(client, client->surface->x, client->surface->y-1);
-	assert(client->input->pointer->focus == client->surface);
-	assert(client->test->pointer_y == client->surface->y);
+	test_assert_ptr_eq(client->input->pointer->focus, client->surface);
+	test_assert_int_eq(client->test->pointer_y, client->surface->y);
 
 	/* x+width (outside boundary) */
 	move_pointer(client, client->surface->x+client->surface->width,
 		     client->surface->y);
-	assert(client->input->pointer->focus == client->surface);
-	assert(client->test->pointer_x ==
-	       client->surface->x+client->surface->width-1);
+	test_assert_ptr_eq(client->input->pointer->focus, client->surface);
+	test_assert_int_eq(client->test->pointer_x,
+			   client->surface->x+client->surface->width-1);
 
 	/* y+height (outside boundary) */
 	move_pointer(client, client->surface->x,
 		     client->surface->y+client->surface->height);
-	assert(client->input->pointer->focus == client->surface);
-	assert(client->test->pointer_y ==
-	       client->surface->y+client->surface->height-1);
+	test_assert_ptr_eq(client->input->pointer->focus, client->surface);
+	test_assert_int_eq(client->test->pointer_y,
+			   client->surface->y+client->surface->height-1);
 
 	confine_destroy(&cs, client);
 	/* x-1 (after unconfinement) */
 	move_pointer(client, client->surface->x-1, client->surface->y);
-	assert(client->input->pointer->focus != client->surface);
-	assert(client->test->pointer_x == client->surface->x-1);
+	test_assert_ptr_ne(client->input->pointer->focus, client->surface);
+	test_assert_int_eq(client->test->pointer_x, client->surface->x-1);
 
 	constraint_deinit(&cs);
 	client_destroy(client);
+
+	return RESULT_OK;
 }
 
 TEST(constraints_locked_boundaries_input_region)
@@ -302,26 +306,28 @@ TEST(constraints_locked_boundaries_input_region)
 
 	lock_pointer(&cs, client, &locked_pointer_listener, NULL,
 		     ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_ONESHOT);
-	assert(cs.pointer_is_locked);
+	test_assert_true(cs.pointer_is_locked);
 
 	/* x-1 (outside surface) */
 	move_pointer(client, client->surface->x-1, client->surface->y);
-	assert(client->input->pointer->focus == client->surface);
-	assert(client->test->pointer_x == client->surface->x);
+	test_assert_ptr_eq(client->input->pointer->focus, client->surface);
+	test_assert_int_eq(client->test->pointer_x, client->surface->x);
 
 	/* x+1 (inside surface) */
 	move_pointer(client, client->surface->x+1, client->surface->y);
-	assert(client->input->pointer->focus == client->surface);
-	assert(client->test->pointer_x == client->surface->x);
+	test_assert_ptr_eq(client->input->pointer->focus, client->surface);
+	test_assert_int_eq(client->test->pointer_x, client->surface->x);
 
 	lock_destroy(&cs, client);
 	/* x-1 (after unlocking) */
 	move_pointer(client, client->surface->x-1, client->surface->y);
-	assert(client->input->pointer->focus != client->surface);
-	assert(client->test->pointer_x == client->surface->x-1);
+	test_assert_ptr_ne(client->input->pointer->focus, client->surface);
+	test_assert_int_eq(client->test->pointer_x, client->surface->x-1);
 
 	constraint_deinit(&cs);
 	client_destroy(client);
+
+	return RESULT_OK;
 }
 
 TEST(constraints_already_constrained)
@@ -339,7 +345,7 @@ TEST(constraints_already_constrained)
 	/* try to lock an already confined pointer */
 	confine_pointer(&cs, client, &confined_pointer_listener, NULL,
 			ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_ONESHOT);
-	assert(cs.pointer_is_confined);
+	test_assert_true(cs.pointer_is_confined);
 	cs.zwp_locked_pointer =
 		zwp_pointer_constraints_v1_lock_pointer(cs.zwp_pointer_constraints,
 							client->surface->wl_surface,
@@ -363,7 +369,7 @@ TEST(constraints_already_constrained)
 	/* try to confine an already locked pointer */
 	lock_pointer(&cs, client, &locked_pointer_listener, NULL,
 		     ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_ONESHOT);
-	assert(cs.pointer_is_locked);
+	test_assert_true(cs.pointer_is_locked);
 	cs.zwp_confined_pointer =
 		zwp_pointer_constraints_v1_confine_pointer(cs.zwp_pointer_constraints,
 							   client->surface->wl_surface,
@@ -377,6 +383,8 @@ TEST(constraints_already_constrained)
 
 	constraint_deinit(&cs);
 	client_destroy(client);
+
+	return RESULT_OK;
 }
 
 /*
@@ -397,7 +405,7 @@ TEST(constraints_shell_activate_input)
 
 	confine_pointer(&cs, client, &confined_pointer_listener, NULL,
 			ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_ONESHOT);
-	assert(!cs.pointer_is_confined);
+	test_assert_false(cs.pointer_is_confined);
 
 	/*
 	 * This mimics the desktop shell when activating input for the view in
@@ -406,15 +414,17 @@ TEST(constraints_shell_activate_input)
 	weston_test_activate_surface(client->test->weston_test,
 				     client->surface->wl_surface);
 	client_roundtrip(client);
-	assert(!cs.pointer_is_confined);
+	test_assert_false(cs.pointer_is_confined);
 
 	/* activation that comes from clicking inside the surface */
 	click_pointer(client);
 	client_roundtrip(client);
-	assert(cs.pointer_is_confined);
+	test_assert_true(cs.pointer_is_confined);
 
 	constraint_deinit(&cs);
 	client_destroy(client);
+
+	return RESULT_OK;
 }
 
 TEST(constraints_pointer_focus)
@@ -427,7 +437,7 @@ TEST(constraints_pointer_focus)
 
 	confine_pointer(&cs, client, &confined_pointer_listener, NULL,
 			ZWP_POINTER_CONSTRAINTS_V1_LIFETIME_ONESHOT);
-	assert(!cs.pointer_is_confined);
+	test_assert_false(cs.pointer_is_confined);
 
 	/* focus out */
 	move_pointer(client, 0, 0);
@@ -435,16 +445,18 @@ TEST(constraints_pointer_focus)
 	/* focus in: should not confine */
 	move_pointer(client, 150, 150);
 	client_roundtrip(client);
-	assert(!cs.pointer_is_confined);
+	test_assert_false(cs.pointer_is_confined);
 
 	/* confine */
 	click_pointer(client);
-	assert(cs.pointer_is_confined);
+	test_assert_true(cs.pointer_is_confined);
 
 	/* focus out: should not unconfine */
 	move_pointer(client, 0, 0);
-	assert(cs.pointer_is_confined);
+	test_assert_true(cs.pointer_is_confined);
 
 	constraint_deinit(&cs);
 	client_destroy(client);
+
+	return RESULT_OK;
 }
